@@ -1,5 +1,5 @@
 
-/*	$Id: tixImgXpm.c,v 1.1.1.1 2000/05/17 11:08:42 idiscovery Exp $	*/
+/*	$Id: tixImgXpm.c,v 1.1.1.1.2.1 2002/12/15 04:21:53 idiscovery Exp $	*/
 
 /*
  * tixImgXpm.c --
@@ -77,12 +77,14 @@ static Tk_ConfigSpec configSpecs[] = {
 
 Tk_ImageType tixPixmapImageType = {
     "pixmap",			/* name */
-    ImgXpmCreate,		/* createProc */
+    (Tk_ImageCreateProc *) ImgXpmCreate,		/* createProc */
     ImgXpmGet,			/* getProc */
     ImgXpmDisplay,		/* displayProc */
     ImgXpmFree,			/* freeProc */
     ImgXpmDelete,		/* deleteProc */
-    (Tk_ImageType *) NULL	/* nextPtr */
+    NULL, 			/* postscriptProc */
+    NULL,			/* nextPtr */
+    NULL, 			/* reserved */
 };
 
 /*
